<?php
/**
 * Fashion Blogs Theme Customizer
 *
 * @link: https://developer.wordpress.org/themes/customize-api/customizer-objects/
 *
 * @package Fashion Blogs
 */

use WPTRT\Customize\Section\Fashion_Blogs_Button;

add_action( 'customize_register', function( $manager ) {

    $manager->register_section_type( Fashion_Blogs_Button::class );

    $manager->add_section(
        new Fashion_Blogs_Button( $manager, 'fashion_blogs_pro', [
            'title'       => __( 'Fashion Blogs Pro', 'fashion-blogs' ),
            'priority'    => 0,
            'button_text' => __( 'GET PREMIUM', 'fashion-blogs' ),
            'button_url'  => esc_url( 'https://www.themagnifico.net/themes/fashion-blog-wordpress-theme/', 'fashion-blogs')
        ] )
    );

} );

// Load the JS and CSS.
add_action( 'customize_controls_enqueue_scripts', function() {

    $version = wp_get_theme()->get( 'Version' );

    wp_enqueue_script(
        'fashion-blogs-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/js/customize-controls.js' ),
        [ 'customize-controls' ],
        $version,
        true
    );

    wp_enqueue_style(
        'fashion-blogs-customize-section-button',
        get_theme_file_uri( 'vendor/wptrt/customize-section-button/public/css/customize-controls.css' ),
        [ 'customize-controls' ],
        $version
    );

} );

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function fashion_blogs_customize_register($wp_customize){
    $wp_customize->get_setting('blogname')->transport = 'postMessage';
    $wp_customize->get_setting('blogdescription')->transport = 'postMessage';

    // General Settings
     $wp_customize->add_section('fashion_blogs_general_settings',array(
        'title' => esc_html__('General Settings','fashion-blogs'),
        'description' => esc_html__('General settings of our theme.','fashion-blogs'),
        'priority'   => 30,
    ));

     $wp_customize->add_setting('fashion_blogs_sticky_header', array(
        'default' => false,
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_sticky_header',array(
        'label'          => __( 'Show Sticky Header', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_sticky_header',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting('fashion_blogs_preloader_hide', array(
        'default' => '1',
        'sanitize_callback' => 'fashion_blogs_sanitize_checkbox'
    ));
    $wp_customize->add_control( new WP_Customize_Control($wp_customize,'fashion_blogs_preloader_hide',array(
        'label'          => __( 'Show Theme Preloader', 'fashion-blogs' ),
        'section'        => 'fashion_blogs_general_settings',
        'settings'       => 'fashion_blogs_preloader_hide',
        'type'           => 'checkbox',
    )));

    $wp_customize->add_setting( 'fashion_blogs_preloader_bg_color', array(
        'default' => '#000',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_bg_color', array(
        'label' => esc_html__('Preloader Background Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_bg_color' 
    )));
    
    $wp_customize->add_setting( 'fashion_blogs_preloader_dot_1_color', array(
        'default' => '#fff',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_dot_1_color', array(
        'label' => esc_html__('Preloader First Dot Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_dot_1_color' 
    )));

    $wp_customize->add_setting( 'fashion_blogs_preloader_dot_2_color', array(
        'default' => '#fd4597',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_preloader_dot_2_color', array(
        'label' => esc_html__('Preloader Second Dot Color','fashion-blogs'),
        'section' => 'fashion_blogs_general_settings',
        'settings' => 'fashion_blogs_preloader_dot_2_color' 
    )));

    // Theme Color
    $wp_customize->add_section('fashion_blogs_color_option',array(
        'title' => esc_html__('Theme Color','fashion-blogs'),
        'description' => esc_html__('Change theme color on one click.','fashion-blogs'),
        'priority'   => 20
    ));

    $wp_customize->add_setting( 'fashion_blogs_theme_color', array(
        'default' => '#fd4597',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_theme_color', array(
        'label' => esc_html__('First Color Option','fashion-blogs'),
        'section' => 'fashion_blogs_color_option',
        'settings' => 'fashion_blogs_theme_color' 
    )));

    $wp_customize->add_setting( 'fashion_blogs_theme_color_2', array(
        'default' => '#101138',
        'sanitize_callback' => 'sanitize_hex_color'
    ));
    $wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'fashion_blogs_theme_color_2', array(
        'label' => esc_html__('Second Color Option','fashion-blogs'),
        'section' => 'fashion_blogs_color_option',
        'settings' => 'fashion_blogs_theme_color_2' 
    )));
    
    // Top Header
    $wp_customize->add_section('fashion_blogs_top_header',array(
        'title' => esc_html__('Top Header','fashion-blogs'),
    ));
    
    $wp_customize->add_setting('fashion_blogs_topbar_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    )); 
    $wp_customize->add_control('fashion_blogs_topbar_text',array(
        'label' => esc_html__('Top Header Text','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_topbar_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_facebook_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_facebook_url',array(
        'label' => esc_html__('Facebook Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_facebook_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_twitter_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_twitter_url',array(
        'label' => esc_html__('Twitter Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_twitter_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_intagram_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_intagram_url',array(
        'label' => esc_html__('Intagram Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_intagram_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_linkedin_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_linkedin_url',array(
        'label' => esc_html__('Linkedin Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_linkedin_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_pintrest_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_pintrest_url',array(
        'label' => esc_html__('Pinterest Link','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_pintrest_url',
        'type'  => 'url'
    ));

    $wp_customize->add_setting('fashion_blogs_subscribe_text',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    )); 
    $wp_customize->add_control('fashion_blogs_subscribe_text',array(
        'label' => esc_html__('Subscribe Text','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_subscribe_text',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_subscribe_url',array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )); 
    $wp_customize->add_control('fashion_blogs_subscribe_url',array(
        'label' => esc_html__('Subscribe URL','fashion-blogs'),
        'section' => 'fashion_blogs_top_header',
        'setting' => 'fashion_blogs_subscribe_url',
        'type'  => 'url'
    ));

    //Slider
    $wp_customize->add_section('fashion_blogs_top_slider',array(
        'title' => esc_html__('Slider Option','fashion-blogs')
    ));

    for ( $count = 1; $count <= 3; $count++ ) {
        $wp_customize->add_setting( 'fashion_blogs_top_slider_page' . $count, array(
            'default'           => '',
            'sanitize_callback' => 'fashion_blogs_sanitize_dropdown_pages'
        ) );
        $wp_customize->add_control( 'fashion_blogs_top_slider_page' . $count, array(
            'label'    => __( 'Select Slide Page', 'fashion-blogs' ),
            'section'  => 'fashion_blogs_top_slider',
            'type'     => 'dropdown-pages'
        ) );
    }

    // Latest Post Section
    $wp_customize->add_section('fashion_blogs_latest_post',array(
        'title' => esc_html__('Latest Post Section','fashion-blogs')
    ));

    $wp_customize->add_setting('fashion_blogs_latest_post_title',array(
        'default' => '',
        'sanitize_callback' => 'sanitize_text_field'
    )); 
    $wp_customize->add_control('fashion_blogs_latest_post_title',array(
        'label' => esc_html__('Section Title','fashion-blogs'),
        'section' => 'fashion_blogs_latest_post',
        'setting' => 'fashion_blogs_latest_post_title',
        'type'  => 'text'
    ));

    $wp_customize->add_setting('fashion_blogs_latest_post_loop',array(
        'default'   => '',
        'sanitize_callback' => 'sanitize_text_field'
    )); 
    $wp_customize->add_control('fashion_blogs_latest_post_loop',array(
        'label' => esc_html__('No of latest post','fashion-blogs'),
        'section'   => 'fashion_blogs_latest_post',
        'type'      => 'number',
        'input_attrs' => array(
            'step'             => 1,
            'min'              => 0,
            'max'              => 12,
        ),
    ));

    $latest_post_loop = get_theme_mod('fashion_blogs_latest_post_loop');

    $args = array('numberposts' => -1);
    $post_list = get_posts($args);
    $i = 1;
    $pst_sls[]= __('Select','fashion-blogs');
    foreach ($post_list as $key => $p_post) {
        $pst_sls[$p_post->ID]=$p_post->post_title;
    }
    for ( $i = 1; $i <= $latest_post_loop; $i++ ) {
        $wp_customize->add_setting('fashion_blogs_other_latest_post_section'.$i,array(
            'sanitize_callback' => 'fashion_blogs_sanitize_choices',
        ));
        $wp_customize->add_control('fashion_blogs_other_latest_post_section'.$i,array(
            'type'    => 'select',
            'choices' => $pst_sls,
            'label' => __('Select Post','fashion-blogs'),
            'section' => 'fashion_blogs_latest_post',
        ));
    }
    wp_reset_postdata();
    
    // Footer
    $wp_customize->add_section('fashion_blogs_site_footer_section', array(
        'title' => esc_html__('Footer', 'fashion-blogs'),
    ));

    $wp_customize->add_setting('fashion_blogs_footer_text_setting', array(
        'sanitize_callback' => 'sanitize_text_field',
    ));
    $wp_customize->add_control('fashion_blogs_footer_text_setting', array(
        'label' => __('Replace the footer text', 'fashion-blogs'),
        'section' => 'fashion_blogs_site_footer_section',
        'priority' => 1,
        'type' => 'text',
    ));
}
add_action('customize_register', 'fashion_blogs_customize_register');

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function fashion_blogs_customize_partial_blogname(){
    bloginfo('name');
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function fashion_blogs_customize_partial_blogdescription(){
    bloginfo('description');
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function fashion_blogs_customize_preview_js(){
    wp_enqueue_script('fashion-blogs-customizer', esc_url(get_template_directory_uri()) . '/assets/js/customizer.js', array('customize-preview'), '20151215', true);
}
add_action('customize_preview_init', 'fashion_blogs_customize_preview_js');